/*
 Generic Runtime Library (GRT)
 Copyright (C) 2005 MySQL AB

 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Lesser General Public
 License as published by the Free Software Foundation; either
 version 2.1 of the License, or (at your option) any later version.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Lesser General Public License for more details.

 You should have received a copy of the GNU Lesser General Public
 License along with this library; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package com.mysql.grt.db;

public class SimpleDatatype extends com.mysql.grt.GrtObject {

    protected SimpleDatatype() {
    }

    public SimpleDatatype(Object obj) {
        super();

        if ((obj == null) || (obj instanceof com.mysql.grt.GrtObject)) {
            data = new SimpleDatatypeDataLocal(this);

            data.setOwner((com.mysql.grt.GrtObject) obj);
            com.mysql.grt.Grt.getInstance().addToObjectCache(this);
        } else if (obj instanceof String) {
            data = new SimpleDatatypeDataGlobal((String) obj);
        }
    }

    public int getCharacterMaximumLength() {
        return ((SimpleDatatypeData) data).getCharacterMaximumLength();
    }

    public int setCharacterMaximumLength(int characterMaximumLength) {
        ((SimpleDatatypeData) data).setCharacterMaximumLength(characterMaximumLength);

        return getCharacterMaximumLength();
    }

    public int getCharacterOctetLength() {
        return ((SimpleDatatypeData) data).getCharacterOctetLength();
    }

    public int setCharacterOctetLength(int characterOctetLength) {
        ((SimpleDatatypeData) data).setCharacterOctetLength(characterOctetLength);

        return getCharacterOctetLength();
    }

    public int getNumericPrecision() {
        return ((SimpleDatatypeData) data).getNumericPrecision();
    }

    public int setNumericPrecision(int numericPrecision) {
        ((SimpleDatatypeData) data).setNumericPrecision(numericPrecision);

        return getNumericPrecision();
    }

    public int getNumericPrecisionRadix() {
        return ((SimpleDatatypeData) data).getNumericPrecisionRadix();
    }

    public int setNumericPrecisionRadix(int numericPrecisionRadix) {
        ((SimpleDatatypeData) data).setNumericPrecisionRadix(numericPrecisionRadix);

        return getNumericPrecisionRadix();
    }

    public int getNumericScale() {
        return ((SimpleDatatypeData) data).getNumericScale();
    }

    public int setNumericScale(int numericScale) {
        ((SimpleDatatypeData) data).setNumericScale(numericScale);

        return getNumericScale();
    }

    public int getDateTimePrecision() {
        return ((SimpleDatatypeData) data).getDateTimePrecision();
    }

    public int setDateTimePrecision(int dateTimePrecision) {
        ((SimpleDatatypeData) data).setDateTimePrecision(dateTimePrecision);

        return getDateTimePrecision();
    }

    public com.mysql.grt.GrtStringList getSynonyms() {
        return ((SimpleDatatypeData) data).getSynonyms();
    }

    public com.mysql.grt.GrtStringList setSynonyms(com.mysql.grt.GrtStringList synonyms) {
        ((SimpleDatatypeData) data).setSynonyms(synonyms);

        return getSynonyms();
    }

    public com.mysql.grt.GrtStringList getFlags() {
        return ((SimpleDatatypeData) data).getFlags();
    }

    public com.mysql.grt.GrtStringList setFlags(com.mysql.grt.GrtStringList flags) {
        ((SimpleDatatypeData) data).setFlags(flags);

        return getFlags();
    }

    public com.mysql.grt.db.DatatypeGroup getGroup() {
        return ((SimpleDatatypeData) data).getGroup();
    }

    public com.mysql.grt.db.DatatypeGroup setGroup(com.mysql.grt.db.DatatypeGroup group) {
        ((SimpleDatatypeData) data).setGroup(group);

        return getGroup();
    }

    public String getGroupById() {
        return ((SimpleDatatypeData) data).getGroupById();
    }

    public void setGroupById(String group) {
        ((SimpleDatatypeData) data).setGroupById(group);
    }

    public StringBuffer getGrtXmlMembers(StringBuffer xml) {
        super.getGrtXmlMembers(xml);

            xml.append("<value type=\"int\" key=\"characterMaximumLength\">"
                    + Integer.toString(getCharacterMaximumLength()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"characterOctetLength\">"
                    + Integer.toString(getCharacterOctetLength()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"numericPrecision\">"
                    + Integer.toString(getNumericPrecision()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"numericPrecisionRadix\">"
                    + Integer.toString(getNumericPrecisionRadix()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"numericScale\">"
                    + Integer.toString(getNumericScale()) + "</value>\n");

            xml.append("<value type=\"int\" key=\"dateTimePrecision\">"
                    + Integer.toString(getDateTimePrecision()) + "</value>\n");

            if (getSynonyms() != null) {
                getSynonyms().getGrtXml(xml, " key=\"synonyms\"");
            }

            if (getFlags() != null) {
                getFlags().getGrtXml(xml, " key=\"flags\"");
            }

            if (getGroup() != null) {
                xml.append("<value type=\"string\" option=\"ref\" key=\"group\">"
                        + getGroupById() + "</value>\n");
            }

        return xml;
    }
}
